@@ -1,10 +1,15 @@
 package Apache2::AuthCookie;
+BEGIN {
+  $Apache2::AuthCookie::VERSION = '3.13';
+}
+
+# ABSTRACT: Perl Authentication and Authorization via cookies
 
 use strict;
 
 use Carp;
 use CGI '3.12';
-use mod_perl2 '1.9922';
+use mod_perl2 '1.99022';
 
 use Apache::AuthCookie::Util;
 use Apache2::RequestRec;
@@ -15,10 +20,6 @@ use Apache2::Response;
 use Apache2::Util;
 use APR::Table;
 use Apache2::Const qw(:common M_GET HTTP_FORBIDDEN HTTP_MOVED_TEMPORARILY);
-use vars qw($VERSION);
-
-# $Id: AuthCookie.pm 227 2008-04-16 14:59:56Z mschout $
-$VERSION = '3.12';
 
 sub recognize_user {
     my ($self, $r) = @_;
@@ -517,12 +518,18 @@ sub get_cookie_path {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 Apache2::AuthCookie - Perl Authentication and Authorization via cookies
 
+=head1 VERSION
+
+version 3.13
+
 =head1 SYNOPSIS
 
 Make sure your mod_perl is at least 1.24, with StackedHandlers,
@@ -595,14 +602,10 @@ MethodHandlers, Authen, and Authz compiled in.
 
 =head1 DESCRIPTION
 
-WARNING! This is an early version of B<Apache::AuthCookie> for mod_perl version
-2.  If you are running under mod_perl version 2, this module should be
-considered of beta quality.  If you are a subclass author and would like to see
-additional changes (besides those listed in README.modperl2) to the interface
-provided by this module under mod_perl version 2, please contact me at
-mschout@gkg.net.  The interface for mod_perl version 1 has not changed.
+This module is for mod_perl version 2.  If you are running mod_perl version 1,
+you should be using B<Apache::AuthCookie> instead.
 
-B<Apache::AuthCookie> allows you to intercept a user's first
+B<Apache2::AuthCookie> allows you to intercept a user's first
 unauthenticated access to a protected document. The user will be
 presented with a custom form where they can enter authentication
 credentials. The credentials are posted to the server where AuthCookie
@@ -700,8 +703,7 @@ displaying the user's credentials in the Location field. They don't really
 change AuthCookie's model, but they do add another round-trip request to the
 client.
 
-=for html
-<PRE>
+=for html <PRE>
 
  (-----------------------)     +---------------------------------+
  ( Request a protected   )     | AuthCookie sets custom error    |
@@ -768,12 +770,11 @@ client.
     create must be able to determine if this session_key is valid and
     map it back to the originally authenticated user ID.
 
-=for html
-</PRE>
+=for html </PRE>
 
 =head1 METHODS
 
-C<Apache::AuthCookie> has several methods you should know about.  Here
+C<Apache2::AuthCookie> has several methods you should know about.  Here
 is the documentation for each. =)
 
 =over 4
@@ -801,7 +802,7 @@ return OK on success and HTTP_FORBIDDEN on failure.
 =item * authen_cred()
 
 You must define this method yourself in your subclass of
-C<Apache::AuthCookie>.  Its job is to create the session key that will
+C<Apache2::AuthCookie>.  Its job is to create the session key that will
 be preserved in the user's cookie.  The arguments passed to it are:
 
  sub authen_cred ($$\@) {
@@ -824,7 +825,7 @@ doesn't tamper with the session key.  More info in the Eagle book.
 =item * authen_ses_key()
 
 You must define this method yourself in your subclass of
-Apache::AuthCookie.  Its job is to look at a session key and determine
+Apache2::AuthCookie.  Its job is to look at a session key and determine
 whether it is valid.  If so, it returns the username of the
 authenticated user.
 
@@ -867,7 +868,7 @@ again').
     return($CODE);
   }
           
-  where CODE is a valid code from Apache::Constants
+  where CODE is a valid code from Apache2::Const
 
 =item * login()
 
@@ -925,7 +926,7 @@ only limited set of characters.
 
 =head1 EXAMPLE
 
-For an example of how to use Apache::AuthCookie, you may want to check
+For an example of how to use Apache2::AuthCookie, you may want to check
 out the test suite, which runs AuthCookie through a few of its paces.
 The documents are located in t/eg/, and you may want to peruse
 t/real.t to see the generated httpd.conf file (at the bottom of
@@ -1030,22 +1031,12 @@ Now C<authen_ses_key()> looks up the C<$ses_key> passed to it and
 returns the saved login.  I use Oracle to store the session key and
 retrieve it later, see the ToDo section below for some other ideas.
 
-=head1 KNOWN LIMITATIONS
-
-If the first unauthenticated request is a POST, it will be changed to
-a GET after the user fills out the login forms, and POSTed data will
-be lost.
-
 =head2 TO DO
 
 =over 4
 
 =item *
 
-There ought to be a way to solve the POST problem in the LIMITATIONS
-section.  It involves being able to re-insert the POSTed content into
-the request stream after the user authenticates.
-
 It might be nice if the logout method could accept some parameters
 that could make it easy to redirect the user to another URI, or
 whatever.  I'd have to think about the options needed before I
@@ -1053,13 +1044,7 @@ implement anything, though.
 
 =back
 
-=head1 CVS REVISION
-
-$Id: AuthCookie.pm 227 2008-04-16 14:59:56Z mschout $
-
-=head1 AUTHOR
-
-Michael Schout <mschout@gkg.net>
+=head1 HISTORY
 
 Originally written by Eric Bartley <bartley@purdue.edu>
 
@@ -1076,6 +1061,34 @@ the same terms as Perl itself.
 
 L<perl(1)>, L<mod_perl(1)>, L<Apache(1)>.
 
+=head1 AUTHOR
+
+  Michael Schout <mschout@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2000 by Ken Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 SOURCE
+
+You can contribute or fork this project via github:
+
+http://github.com/mschout/apache-authcookie
+
+ git clone git://github.com/mschout/apache-authcookie.git
+
+=head1 BUGS
+
+Please report any bugs or feature requests to bug-apache-authcookie@rt.cpan.org or through the web interface at:
+ http://rt.cpan.org/Public/Dist/Display.html?Name=Apache-AuthCookie
+
 =cut
 
+
+__END__
+
+
 # vim: sw=4 ts=4 ai et
